==> fred-backend-registry_2.22.0.orig.tar.gz: fred-backend-registry-2.22.0/test/client.cc <==
/*
 * Copyright (C) 2022-2024  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "fred_api/registry/contact/service_contact_grpc.pb.h"
#include "fred_api/registry/contact/service_contact_grpc.grpc.pb.h"
#include "fred_api/registry/domain/service_admin_grpc.pb.h"
#include "fred_api/registry/domain/service_admin_grpc.grpc.pb.h"
#include "fred_api/registry/domain/service_domain_grpc.pb.h"
#include "fred_api/registry/domain/service_domain_grpc.grpc.pb.h"

#include <google/protobuf/util/json_util.h>

#include <grpc/grpc.h>
#include <grpcpp/channel.h>
#include <grpcpp/client_context.h>
#include <grpcpp/create_channel.h>
#include <grpcpp/security/credentials.h>

#include <cstdlib>
#include <iostream>
#include <map>
#include <stdexcept>

namespace {

std::string to_json(const google::protobuf::Message& msg)
{
    std::string json;
    google::protobuf::util::JsonPrintOptions options;
    options.add_whitespace = true;
    options.preserve_proto_field_names = true;
    const auto status = google::protobuf::util::MessageToJsonString(msg, &json, options);
    if (status.ok())
    {
        return json;
    }
    throw std::runtime_error{"unable convert to json"};
}

int get_domains_by_contact(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Domain::NewStub(channel);
    Fred::Registry::Api::Domain::DomainsByContactRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::DomainsByContactReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientReader<Fred::Registry::Api::Domain::DomainsByContactReply>> reader(
            stub->get_domains_by_contact(&context, request));
    while (reader->Read(&reply))
    {
        std::cout << to_json(reply) << std::endl;
    }
    const auto status = reader->Finish();
    if (status.ok())
    {
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int get_domains_outzone_notify_info(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Admin::NewStub(channel);
    Fred::Registry::Api::Domain::GetDomainsOutzoneNotifyInfoRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::GetDomainsNotifyInfoReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientReader<Fred::Registry::Api::Domain::GetDomainsNotifyInfoReply>> reader(
            stub->get_domains_outzone_notify_info(&context, request));
    while (reader->Read(&reply))
    {
        std::cout << to_json(reply) << std::endl;
    }
    const auto status = reader->Finish();
    if (status.ok())
    {
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int update_domains_outzone_additional_notify_info(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Admin::NewStub(channel);
    Fred::Registry::Api::Domain::UpdateDomainsOutzoneAdditionalNotifyInfoRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::UpdateDomainsAdditionalNotifyInfoReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientWriter<Fred::Registry::Api::Domain::UpdateDomainsOutzoneAdditionalNotifyInfoRequest>> writer(
            stub->update_domains_outzone_additional_notify_info(&context, &reply));
    if (!writer->Write(request))
    {
        std::cerr << "write failure: stream broken" << std::endl;
        return EXIT_FAILURE;
    }
    writer->WritesDone();
    const auto status = writer->Finish();
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int get_domain_life_cycle_stage(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Domain::NewStub(channel);
    Fred::Registry::Api::Domain::DomainLifeCycleStageRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::DomainLifeCycleStageReply reply;
    grpc::ClientContext context;
    const auto status = stub->get_domain_life_cycle_stage(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int update_contact_state(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Contact::Contact::NewStub(channel);
    Fred::Registry::Api::Contact::UpdateContactStateRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Contact::UpdateContactStateReply reply;
    grpc::ClientContext context;
    const auto status = stub->update_contact_state(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int create_contact(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Contact::Contact::NewStub(channel);
    Fred::Registry::Api::Contact::CreateContactRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.error_message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Contact::CreateContactReply reply;
    grpc::ClientContext context;
    const auto status = stub->create_contact(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

using GrpcFnc = int(*)(const char*, const char*);

const std::map<std::string, GrpcFnc> methods = {
        {"get_domains_by_contact", get_domains_by_contact},
        {"get_domains_outzone_notify_info", get_domains_outzone_notify_info},
        {"update_domains_outzone_additional_notify_info", update_domains_outzone_additional_notify_info},
        {"get_domain_life_cycle_stage", get_domain_life_cycle_stage},
        {"update_contact_state", update_contact_state},
        {"create_contact", create_contact}};

}//namespace {anonymous}

int main(int argc, char* argv[])
{
    if (argc != 4)
    {
        std::cerr << "bad number of arguments; 3 arguments expected\n"
                     "usage: " << argv[0] << " <grpc server endpoint> <method> <request in json format>" << std::endl;
        return EXIT_FAILURE;
    }
    char*& endpoint = argv[1];
    char*& requested_method = argv[2];
    char*& json_request = argv[3];
    const auto methods_iter = methods.find(requested_method);
    if (methods_iter == end(methods))
    {
        std::cerr << "unsupported method: " << requested_method << std::endl;
        return EXIT_FAILURE;
    }
    return methods_iter->second(endpoint, json_request);
}

==> fred-backend-registry_2.23.1.orig.tar.gz: fred-backend-registry-2.23.1/test/client.cc <==
/*
 * Copyright (C) 2022-2025  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "fred_api/registry/contact/service_contact_grpc.pb.h"
#include "fred_api/registry/contact/service_contact_grpc.grpc.pb.h"
#include "fred_api/registry/domain/service_admin_grpc.pb.h"
#include "fred_api/registry/domain/service_admin_grpc.grpc.pb.h"
#include "fred_api/registry/domain/service_domain_grpc.pb.h"
#include "fred_api/registry/domain/service_domain_grpc.grpc.pb.h"

#include <google/protobuf/util/json_util.h>

#include <grpc/grpc.h>
#include <grpcpp/channel.h>
#include <grpcpp/client_context.h>
#include <grpcpp/create_channel.h>
#include <grpcpp/security/credentials.h>

#include <cstdlib>
#include <iostream>
#include <map>
#include <stdexcept>

namespace {

std::string to_json(const google::protobuf::Message& msg)
{
    std::string json;
    google::protobuf::util::JsonPrintOptions options;
    options.add_whitespace = true;
    options.preserve_proto_field_names = true;
    const auto status = google::protobuf::util::MessageToJsonString(msg, &json, options);
    if (status.ok())
    {
        return json;
    }
    throw std::runtime_error{"unable convert to json"};
}

int get_domains_by_contact(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Domain::NewStub(channel);
    Fred::Registry::Api::Domain::DomainsByContactRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::DomainsByContactReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientReader<Fred::Registry::Api::Domain::DomainsByContactReply>> reader(
            stub->get_domains_by_contact(&context, request));
    while (reader->Read(&reply))
    {
        std::cout << to_json(reply) << std::endl;
    }
    const auto status = reader->Finish();
    if (status.ok())
    {
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int get_domains_outzone_notify_info(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Admin::NewStub(channel);
    Fred::Registry::Api::Domain::GetDomainsOutzoneNotifyInfoRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::GetDomainsNotifyInfoReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientReader<Fred::Registry::Api::Domain::GetDomainsNotifyInfoReply>> reader(
            stub->get_domains_outzone_notify_info(&context, request));
    while (reader->Read(&reply))
    {
        std::cout << to_json(reply) << std::endl;
    }
    const auto status = reader->Finish();
    if (status.ok())
    {
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int update_domains_outzone_additional_notify_info(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Admin::NewStub(channel);
    Fred::Registry::Api::Domain::UpdateDomainsOutzoneAdditionalNotifyInfoRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::UpdateDomainsAdditionalNotifyInfoReply reply;
    grpc::ClientContext context;
    std::unique_ptr<grpc::ClientWriter<Fred::Registry::Api::Domain::UpdateDomainsOutzoneAdditionalNotifyInfoRequest>> writer(
            stub->update_domains_outzone_additional_notify_info(&context, &reply));
    if (!writer->Write(request))
    {
        std::cerr << "write failure: stream broken" << std::endl;
        return EXIT_FAILURE;
    }
    writer->WritesDone();
    const auto status = writer->Finish();
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int get_domain_life_cycle_stage(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Domain::Domain::NewStub(channel);
    Fred::Registry::Api::Domain::DomainLifeCycleStageRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Domain::DomainLifeCycleStageReply reply;
    grpc::ClientContext context;
    const auto status = stub->get_domain_life_cycle_stage(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int update_contact_state(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Contact::Contact::NewStub(channel);
    Fred::Registry::Api::Contact::UpdateContactStateRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Contact::UpdateContactStateReply reply;
    grpc::ClientContext context;
    const auto status = stub->update_contact_state(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

int create_contact(const char* endpoint, const char* json_request)
{
    auto channel = grpc::CreateChannel(endpoint, grpc::InsecureChannelCredentials());
    auto stub = Fred::Registry::Api::Contact::Contact::NewStub(channel);
    Fred::Registry::Api::Contact::CreateContactRequest request;
    {
        const auto status = google::protobuf::util::JsonStringToMessage(json_request, &request);
        if (!status.ok())
        {
            std::cerr << "not a json: " << status.message() << std::endl;
            return EXIT_FAILURE;
        }
    }
    Fred::Registry::Api::Contact::CreateContactReply reply;
    grpc::ClientContext context;
    const auto status = stub->create_contact(&context, request, &reply);
    if (status.ok())
    {
        std::cout << to_json(reply) << std::endl;
        return EXIT_SUCCESS;
    }
    std::cerr << "failure: " << status.error_message() << std::endl;
    return EXIT_FAILURE;
}

using GrpcFnc = int(*)(const char*, const char*);

const std::map<std::string, GrpcFnc> methods = {
        {"get_domains_by_contact", get_domains_by_contact},
        {"get_domains_outzone_notify_info", get_domains_outzone_notify_info},
        {"update_domains_outzone_additional_notify_info", update_domains_outzone_additional_notify_info},
        {"get_domain_life_cycle_stage", get_domain_life_cycle_stage},
        {"update_contact_state", update_contact_state},
        {"create_contact", create_contact}};

}//namespace {anonymous}

int main(int argc, char* argv[])
{
    if (argc != 4)
    {
        std::cerr << "bad number of arguments; 3 arguments expected\n"
                     "usage: " << argv[0] << " <grpc server endpoint> <method> <request in json format>" << std::endl;
        return EXIT_FAILURE;
    }
    char*& endpoint = argv[1];
    char*& requested_method = argv[2];
    char*& json_request = argv[3];
    const auto methods_iter = methods.find(requested_method);
    if (methods_iter == end(methods))
    {
        std::cerr << "unsupported method: " << requested_method << std::endl;
        return EXIT_FAILURE;
    }
    return methods_iter->second(endpoint, json_request);
}
